@@ -245,6 +245,9 @@ OPERATIONDENIED_UINNOTMATCH = 'OperationDenied.UinNotMatch'
 # The frequency limit of creating sub-users has been reached.
 REQUESTLIMITEXCEEDED_CREATEUSER = 'RequestLimitExceeded.CreateUser'
 
+# The user account limit has been reached.
+REQUESTLIMITEXCEEDED_UINLIMITEXCEEDED = 'RequestLimitExceeded.UinLimitExceeded'
+
 # User group does not exist.
 RESOURCENOTFOUND_GROUPNOTEXIST = 'ResourceNotFound.GroupNotExist'
 
